==> 4.1.2.tar.gz: lib/persistent-tab-view.dart <==
library persistent_bottom_nav_bar_v2;

import 'dart:math';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

//Animations
part 'animations/animations.dart';
part 'models/nav-bar-animation.model.dart';
part 'models/nav-bar-essentials.model.dart';
part 'models/nav-bar-padding.model.dart';
part 'models/neumorphic-properties.widget.dart';
part 'models/page-route-transitions.model.dart';
part 'models/persisten-bottom-nav-item.widget.dart';
part 'models/persistent-bottom-nav-bar-styles.widget.dart';
part 'models/persistent-bottom-nav-bar.widget.dart';
//Models
part 'models/persistent-nav-bar-scaffold.widget.dart';
part 'models/route-settings.model.dart';
part 'models/tab-view.widget.dart';
part 'nav-bar-styles/neumorphic-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/simple-bottom-nav-bar.widget.dart';
//Styles
part 'nav-bar-styles/style-1-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-10-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-11-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-12-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-13-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-14-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-15-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-16-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-17-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-18-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-2-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-3-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-4-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-5-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-6-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-7-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-8-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-9-bottom-nav-bar.widget.dart';
//Neuomorphic-Card
part 'neumorphic-package-by-serge-software/neumorphic-card.dart';
//Main TabView Widget
part 'persistent-tab-view.widget.dart';
//Utils
part 'utils/functions.utils.dart';
part 'utils/navigator-functions.utils.dart';

==> 4.2.1.tar.gz: lib/persistent-tab-view.dart <==
library persistent_bottom_nav_bar_v2;

import 'dart:math';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

//Animations
part 'animations/animations.dart';
part 'models/nav-bar-animation.model.dart';
part 'models/nav-bar-essentials.model.dart';
part 'models/nav-bar-padding.model.dart';
part 'models/neumorphic-properties.widget.dart';
part 'models/page-route-transitions.model.dart';
part 'models/persistent-bottom-nav-item.widget.dart';
part 'models/persistent-bottom-nav-bar-styles.widget.dart';
part 'models/persistent-bottom-nav-bar.widget.dart';
//Models
part 'models/persistent-nav-bar-scaffold.widget.dart';
part 'models/route-settings.model.dart';
part 'models/tab-view.widget.dart';
part 'nav-bar-styles/neumorphic-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/simple-bottom-nav-bar.widget.dart';
//Styles
part 'nav-bar-styles/style-1-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-10-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-11-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-12-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-13-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-14-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-15-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-16-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-17-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-18-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-2-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-3-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-4-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-5-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-6-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-7-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-8-bottom-nav-bar.widget.dart';
part 'nav-bar-styles/style-9-bottom-nav-bar.widget.dart';
//Neuomorphic-Card
part 'neumorphic-package-by-serge-software/neumorphic-card.dart';
//Main TabView Widget
part 'persistent-tab-view.widget.dart';
//Utils
part 'utils/functions.utils.dart';
part 'utils/navigator-functions.utils.dart';
